Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Closer ¶
type Closer interface {
// Close will instruct the Closer to stop and free its resources
Close()
// IsClosed returns a channel that can participate in a select in order
// to determine whether the Closer has been closed
IsClosed() <-chan struct{}
}
Closer is a value whose underlying resources must be explicitly closed
Click to show internal directories.
Click to hide internal directories.